@@ -1,18 +1,8 @@
 import asyncio
 import json
-import http
-from typing import (
-    cast,
-    Any,
-    Dict,
-    Union,
-    List,
-    Iterator,
-    Mapping,
-    AsyncGenerator,
-)
+import typing
+from http import cookies as http_cookies
 
-from starlette.types import Scope, Send, Receive
 from starlette.datastructures import (
     Address,
     URL,
@@ -28,13 +18,40 @@ from starlette.formparsers import (
 )
 from starlette.requests import (
     SERVER_PUSH_HEADERS_TO_COPY,
-    empty_receive,
-    empty_send,
     ClientDisconnect,
 )
 
+from ..types import Scope, Send, Receive, Message
 
-class HTTPConnection(Mapping):
+
+def cookie_parser(cookie_string: str) -> typing.Dict[str, str]:
+    """
+    This function parses a ``Cookie`` HTTP header into a dict of key/value pairs.
+
+    It attempts to mimic browser cookie parsing behavior: browsers and web servers
+    frequently disregard the spec (RFC 6265) when setting and reading cookies,
+    so we attempt to suit the common scenarios here.
+
+    This function has been adapted from Django 3.1.0.
+    Note: we are explicitly _NOT_ using `SimpleCookie.load` because it is based
+    on an outdated spec and will fail on lots of input we want to support
+    """
+    cookie_dict: typing.Dict[str, str] = {}
+    for chunk in cookie_string.split(";"):
+        if "=" in chunk:
+            key, val = chunk.split("=", 1)
+        else:
+            # Assume an empty name per
+            # https://bugzilla.mozilla.org/show_bug.cgi?id=169091
+            key, val = "", chunk
+        key, val = key.strip(), val.strip()
+        if key or val:
+            # unquote using Python's algorithm.
+            cookie_dict[key] = http_cookies._unquote(val)  # type: ignore
+    return cookie_dict
+
+
+class HTTPConnection(typing.Mapping):
     """
     A base class for incoming HTTP connections, that is used to provide
     any functionality that is common to both `Request` and `WebSocket`.
@@ -47,7 +64,7 @@ class HTTPConnection(Mapping):
     def __getitem__(self, key: str) -> str:
         return self.scope[key]
 
-    def __iter__(self) -> Iterator[str]:
+    def __iter__(self) -> typing.Iterator[str]:
         return iter(self.scope)
 
     def __len__(self) -> int:
@@ -84,15 +101,13 @@ class HTTPConnection(Mapping):
         return self._query_params
 
     @property
-    def cookies(self) -> Dict[str, str]:
+    def cookies(self) -> typing.Dict[str, str]:
         if not hasattr(self, "_cookies"):
-            cookies = {}
+            cookies: typing.Dict[str, str] = {}
             cookie_header = self.headers.get("cookie")
+
             if cookie_header:
-                cookie = http.cookies.SimpleCookie()  # type: http.cookies.BaseCookie
-                cookie.load(cookie_header)
-                for key, morsel in cookie.items():
-                    cookies[key] = morsel.value
+                cookies = cookie_parser(cookie_header)
             self._cookies = cookies
         return self._cookies
 
@@ -111,6 +126,14 @@ class HTTPConnection(Mapping):
         return self._state
 
 
+async def empty_receive() -> Message:
+    raise RuntimeError("Receive channel has not been made available")
+
+
+async def empty_send(message: Message) -> None:
+    raise RuntimeError("Send channel has not been made available")
+
+
 class Request(HTTPConnection):
     def __init__(
         self, scope: Scope, receive: Receive = empty_receive, send: Send = empty_send
@@ -130,7 +153,7 @@ class Request(HTTPConnection):
     def receive(self) -> Receive:
         return self._receive
 
-    async def stream(self) -> AsyncGenerator[bytes, None]:
+    async def stream(self) -> typing.AsyncGenerator[bytes, None]:
         if hasattr(self, "_body"):
             yield self._body
             yield b""
@@ -161,7 +184,7 @@ class Request(HTTPConnection):
             self._body = b"".join(chunks)
         return self._body
 
-    async def json(self) -> Any:
+    async def json(self) -> typing.Any:
         if not hasattr(self, "_json"):
             body = await self.body()
             self._json = json.loads(body)
