@@ -2,12 +2,12 @@ import os
 import sys
 from copy import deepcopy
 from inspect import signature
-from typing import List, Dict, Any, Sequence
+from typing import cast, List, Dict, Any, Sequence
 
 if sys.version_info[:2] < (3, 8):
-    from typing_extensions import TypedDict
+    from typing_extensions import TypedDict, Literal
 else:
-    from typing import TypedDict
+    from typing import TypedDict, Literal
 
 from starlette.types import Scope, Receive, Send
 from starlette.endpoints import Request, Response
@@ -37,7 +37,7 @@ class OpenAPI:
         *,
         tags: Dict[str, Tag] = {},
         template: str = "",
-        media_type="yaml",
+        media_type: Literal["yaml", "json"] = "yaml",
     ):
         """
         media_type: yaml or json
@@ -65,13 +65,13 @@ class OpenAPI:
                 else:
                     self.path2tag[path] = [tag_name]
 
-    def _generate_paths(self) -> Dict[str, Any]:
+    def _generate_paths(self, app: Index) -> Dict[str, Any]:
         result = {}
-        for app in reversed(
-            [Index().indexfile]
-            + [app for _, app in Index().mount_apps if isinstance(app, IndexFile)]
+        for subapp in reversed(
+            [app.indexfile]
+            + [subapp for _, subapp in app.mount_apps if isinstance(subapp, IndexFile)]
         ):
-            for view, path in app.get_views():
+            for view, path in subapp.get_views():
                 if not hasattr(view, "HTTP"):
                     continue
                 viewclass = getattr(view, "HTTP")
@@ -147,7 +147,7 @@ class OpenAPI:
                 "description": "Current server",
             }
         ]
-        openapi["paths"] = self._generate_paths()
+        openapi["paths"] = self._generate_paths(cast(Index, request["app"]))
 
         return openapi
 
